==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CellActionManagerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let CellActionManagerDescriptionMetadata = /*@__PURE__*/ (() => {
    class CellActionManagerDescriptionMetadata extends Base {
        static b(a) {
            if (CellActionManagerDescriptionMetadata.a == null) {
                CellActionManagerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CellActionManagerDescriptionMetadata.c(CellActionManagerDescriptionMetadata.a);
            }
            if (a.k(CellActionManagerDescriptionMetadata.a)) {
                return;
            }
            a.aa(CellActionManagerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsControlPressed", "Boolean");
            a.item("IsShiftPressed", "Boolean");
        }
        static d(a) {
            CellActionManagerDescriptionMetadata.b(a);
            a.ab("CellActionManager", CellActionManagerDescriptionMetadata.a);
        }
    }
    CellActionManagerDescriptionMetadata.$t = /*@__PURE__*/ markType(CellActionManagerDescriptionMetadata, 'CellActionManagerDescriptionMetadata');
    CellActionManagerDescriptionMetadata.a = null;
    return CellActionManagerDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/CellActionManagerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let CellActionManagerDescriptionMetadata = /*@__PURE__*/ (() => {
    class CellActionManagerDescriptionMetadata extends Base {
        static b(a) {
            if (CellActionManagerDescriptionMetadata.a == null) {
                CellActionManagerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CellActionManagerDescriptionMetadata.c(CellActionManagerDescriptionMetadata.a);
            }
            if (a.k(CellActionManagerDescriptionMetadata.a)) {
                return;
            }
            a.ac(CellActionManagerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IsControlPressed", "Boolean");
            a.item("IsShiftPressed", "Boolean");
        }
        static d(a) {
            CellActionManagerDescriptionMetadata.b(a);
            a.ad("CellActionManager", CellActionManagerDescriptionMetadata.a);
        }
    }
    CellActionManagerDescriptionMetadata.$t = /*@__PURE__*/ markType(CellActionManagerDescriptionMetadata, 'CellActionManagerDescriptionMetadata');
    CellActionManagerDescriptionMetadata.a = null;
    return CellActionManagerDescriptionMetadata;
})();
